/* 
 * Project name:
     RTCC (Example of using RTCC internal module)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Revision History:
     20110615(FJ):
       - initial release;
 * Description:
     Simple RTCC example which toggles DATA LED every second;
 * Test configuration:
     MCU:             P32MX534F064H
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156G.pdf
     Dev.Board:       MINI-32 Board
                      http://www.mikroe.com/eng/products/view/711/mini-32-board/
     Oscillator:      XT-PLL10x, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/categories/view/89/pic32-compilers/
 * NOTES:
     - None.
 */

sbit Seconds_bit at LATD6_bit;

unsigned long time = 0x04153300;   // set time to 04 hr, 15 min, 33 sec
unsigned long date = 0x06111301;   // set date to Monday 13 Nov 2006

void main() {
  AD1PCFG = 0xFFFF;         // Initialize AN pins as digital
  TRISD = 0;                // Set PORTD as output
  LATD = 0;                 // Clear PORTD

  // RTCC registers unlock procedure
  SYSKEY = 0xAA996655;      // Write first unlock key to SYSKEY
  SYSKEY = 0x556699AA;      // Write second unlock key to SYSKEY

  RTCWREN_bit = 1;          // RTC Value registers can be written to by the user

  RTCOE_bit = 1;            // RTCC pin clock output enabled
  RTSECSEL_bit = 1;         // RTCC Seconds Clock is selected for the RTCC pin

  ON__RTCCON_bit= 0;        // Turn off the RTCC module

  while(RTCCON&0x40)        // Wait for clock to be turned off
    ;
 
  RTCTIME = time;           // Set time
  RTCDATE = date;           // Set date

  ON__RTCCON_bit= 1;        // Turn on the RTCC module

  while(!(RTCCON&0x40))     // Wait for clock to be turned on
    ;

  while(1) {
    Seconds_bit = RTCTIME.F8;   // Toggle Seconds_bit every second
  }                             // RTCTIME.F8 changes every second (see datasheet)
}